<?php
/**
 * Retrieves and creates the wp-config.php file.
 *
 * The permissions for the base directory must allow for writing files in order
 * for the wp-config.php to be created using this page.
 *
 * @package WordPress
 * @subpackage Administration
 */

/**
 * We are installing.
 *
 * @package WordPress
 */
define('WP_INSTALLING', true);

/**#@+
 * These three defines are required to allow us to use require_wp_db() to load
 * the database class while being wp-content/db.php aware.
 * @ignore
 */
define('ABSPATH', dirname(dirname(__FILE__)).'/');
define('WPINC', 'wp-includes');
define('WP_CONTENT_DIR', ABSPATH . 'wp-content');
/**#@-*/

require_once(ABSPATH . WPINC . '/compat.php');
require_once(ABSPATH . WPINC . '/functions.php');
require_once(ABSPATH . WPINC . '/classes.php');

if (!file_exists(ABSPATH . 'wp-config-sample.php'))
	wp_die('Sajnálom, de a működéshez szükség van a wp-config-sample.php fájlra. Kérem újra feltölteni a telepítő csomagból.');

$configFile = file(ABSPATH . 'wp-config-sample.php');

if ( !is_writable(ABSPATH))
	wp_die("Sajnálom, nem tudok írni a könyvtárba. Vagy meg kell változtatni a WordPress telepítési könyvtár hozzáféréseit, vagy kézzel létre kell hozni a wp-config.php fájlt.");

// Check if wp-config.php has been created
if (file_exists(ABSPATH . 'wp-config.php'))
	wp_die("<p>A 'wp-config.php' fájl létezik. Ha szükség van bármilyen beállítási lehetőség újra állításához a fájlban, akkor először le kell törölni. Ezután meg kell próbálni <a href='install.php'> fájlt telepíteni</a>.</p>");

// Check if wp-config.php exists above the root directory
if (file_exists(ABSPATH . '../wp-config.php') && ! file_exists(ABSPATH . '../wp-settings.php'))
	wp_die("<p>A 'wp-config.php' már létezik egy könyvtárral a WordPress telepítési könyvtára felett. Ha bármilyen beállítást újra be szeretnénk állítani, előbb törölni kell a fájlt. Ezután <a href='install.php'>elkezdhetö a telepítés</a>.</p>");

if (isset($_GET['step']))
	$step = $_GET['step'];
else
	$step = 0;

/**
 * Display setup wp-config.php file header.
 *
 * @ignore
 * @since 2.3.0
 * @package WordPress
 * @subpackage Installer_WP_Config
 */
function display_header() {
	header( 'Content-Type: text/html; charset=utf-8' );
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<title>WordPress &rsaquo; telepítési beállítások</title>
<link rel="stylesheet" href="css/install.css" type="text/css" />

</head>
<body>
<h1 id="logo"><img alt="WordPress" src="images/wordpress-logo.png" /></h1>
<?php
}//end function display_header();

switch($step) {
	case 0:
		display_header();
?>

<p>Üdvözöl a WordPress! A telepítés előtt szükségünk van, némi információra az adatbázissal kapcsolatban. A folytatáshoz ismerni kell a következő paramétereket:</p>
<ol>
	<li>Adatbázis neve</li>
	<li>Adatbázis felhasználónév</li>
	<li>Adatbázis jelszó</li>
	<li>Adatbázis szerver címe</li>
	<li>Tábla előtag (ha több, mint egy WordPress szeretném egy adatbázisba telepíteni) </li>
</ol>
<p><strong>Ha bármilyen okból nem működik az automatikus fájl-létrehozás, nem kell aggódni. Csak annyi történik, hogy az adatbázis információkat kitölti a konfigurációs fájlban. Egy szövegszerkesztővel (nem Word!) meg kell nyitni a <code>wp-config-sample.php</code> fájlt és kitölteni az információkat, majd elmenteni <code>wp-config.php</code> néven. </strong></p>
<p>Nagy valószínűséggel az internet szolgáltató megadta ezeket az információkat. Ha mégsem állnak rendelkezésre ezek az adatok, akkor a folytatás előtt fel kell venni a kapcsolatot velük. Ha, készen vagyunk&hellip;</p>

<p class="step"><a href="setup-config.php?step=1" class="button">Lássunk neki!</a></p>
<?php
	break;

	case 1:
		display_header();
	?>
<form method="post" action="setup-config.php?step=2">
	<p>Lejjebb meg kell adni az adatbázis kapcsolat tulajdonságait. Ha nem vagyunk biztosak bennük, fel kell venni a kapcsolatot a szolgáltatóval. </p>
	<table class="form-table">
		<tr>
			<th scope="row">Adatbázis név</th>
			<td><input name="dbname" id="dbname" type="text" size="25" value="wordpress" /></td>
			<td>Az adatbázis neve, amelyben a WP használatba kerül. </td>
		</tr>
		<tr>
			<th scope="row">Felhasználónév</th>
			<td><input name="uname" id="uname" type="text" size="25" value="adatbázis felhasználó név" /></td>
			<td>MySQL felhasználónév</td>
		</tr>
		<tr>
			<th scope="row">Jelszó</th>
			<td><input name="pwd" id="pwd" type="text" size="25" value="adatbázis jelszó" /></td>
			<td>...és a MySQL jelszó.</td>
		</tr>
		<tr>
			<th scope="row">Adatbázis kiszolgáló címe</th>
			<td><input name="dbhost" id="dbhost" type="text" size="25" value="localhost" /></td>
			<td>99%-ig biztos, hogy ezen nem kell változtatni.</td>
		</tr>
		<tr>
			<th scope="row">Tábla előtag</th>
			<td><input name="prefix" id="prefix" type="text" id="prefix" value="wp_" size="25" /></td>
			<td>Ha több WordPress-t szeretnénk telepíteni egy adatbázisra, akkor ezt meg kell változtatni.</td>
		</tr>
	</table>
	<p class="step"><input name="submit" type="submit" value="Mehet!" class="button" /></p>
</form>
<?php
	break;

	case 2:
	$dbname  = trim($_POST['dbname']);
	$uname   = trim($_POST['uname']);
	$passwrd = trim($_POST['pwd']);
	$dbhost  = trim($_POST['dbhost']);
	$prefix  = trim($_POST['prefix']);
	if (empty($prefix)) $prefix = 'wp_';

	// Test the db connection.
	/**#@+
	 * @ignore
	 */
	define('DB_NAME', $dbname);
	define('DB_USER', $uname);
	define('DB_PASSWORD', $passwrd);
	define('DB_HOST', $dbhost);
	/**#@-*/

	// We'll fail here if the values are no good.
	require_wp_db();
	if ( !empty($wpdb->error) )
		wp_die($wpdb->error->get_error_message());

	$handle = fopen(ABSPATH . 'wp-config.php', 'w');

	foreach ($configFile as $line_num => $line) {
		switch (substr($line,0,16)) {
			case "define('DB_NAME'":
				fwrite($handle, str_replace("adatbázisodneve", $dbname, $line));
				break;
			case "define('DB_USER'":
				fwrite($handle, str_replace("'felhasználóneved'", "'$uname'", $line));
				break;
			case "define('DB_PASSW":
				fwrite($handle, str_replace("'jelszavad'", "'$passwrd'", $line));
				break;
			case "define('DB_HOST'":
				fwrite($handle, str_replace("localhost", $dbhost, $line));
				break;
			case '$table_prefix  =':
				fwrite($handle, str_replace('wp_', $prefix, $line));
				break;
			default:
				fwrite($handle, $line);
		}
	}
	fclose($handle);
	chmod(ABSPATH . 'wp-config.php', 0666);

	display_header();
?>
<p>Jól van! A telepítésnek ezzel a részével meg is lennénk. A WordPress most már képes kommunikálni az adatbázissal. Ha készen állunk, itt az ideje&hellip;</p>

<p class="step"><a href="install.php" class="button">Elkezdeni a telepítést</a></p>
<?php
	break;
}
?>
</body>
</html>
